@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 $output = [
 	'header' => $data['title'],
 	'body' => '',
@@ -27,99 +31,113 @@ $output = [
 	'buttons' => null
 ];
 
+$options = $data['options'];
 $controls = [];
 $form = null;
 
-$options = $data['options'];
-$page_filter = $data['page_filter'];
-
 // Construct table header.
-$header_form = (new CForm())->cleanItems();
-foreach ($options as $option_key => $option_value) {
-	if ($option_value === true) {
-		$header_form->addItem((new CVar($option_key, 1))->removeId());
-	}
-	elseif ($option_value) {
-		$header_form->addItem((new CVar($option_key, $option_value))->removeId());
-	}
-}
+$header_form = ($data['popup_type'] === 'help_items') ? (new CForm())->cleanItems() : new CDiv();
+$header_form->setId('generic-popup-form');
 
-// Only host id.
-if (array_key_exists('only_hostid', $options)) {
-	$host = $options['only_hostid'];
+// Make 'empty' button.
+if ($data['popup_type'] === 'triggers' && !array_key_exists('noempty', $options)) {
+	$value1 = (strpos($options['dstfld1'], 'id') !== false) ? 0 : '';
+	$value2 = (strpos($options['dstfld2'], 'id') !== false) ? 0 : '';
+	$value3 = (strpos($options['dstfld3'], 'id') !== false) ? 0 : '';
 
-	if ($host) {
-		$controls[] = [
-			new CLabel(_('Host'), 'hostid'),
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			(new CComboBox('hostid', $host['hostid']))
-				->addItem($host['hostid'], $host['name'])
-				->setEnabled(false)
-				->setTitle(_('You can not switch hosts for current selection.'))
-				->removeId()
-		];
-	}
+	$empty_script = get_window_opener($options['dstfld1'], $value1);
+	$empty_script .= get_window_opener($options['dstfld2'], $value2);
+	$empty_script .= get_window_opener($options['dstfld3'], $value3);
+	$empty_script .= 'overlayDialogueDestroy(jQuery(this).closest("[data-dialogueid]").attr("data-dialogueid"));';
+	$empty_script .= 'return false;';
+
+	$empty_btn = (new CButton('empty', _('Empty')))
+		->addStyle('float: right; margin-left: 5px;')
+		->onClick($empty_script);
 }
 else {
-	// Show Group dropdown in header for these specified sources.
-	$show_group_cmb_box = ['triggers', 'items', 'applications', 'graphs', 'graph_prototypes', 'item_prototypes',
-		'templates', 'hosts', 'host_templates'
-	];
-
-	if (in_array($data['popup_type'], $show_group_cmb_box)
-			&& ($data['popup_type'] !== 'item_prototypes' || !$options['parent_discoveryid'])) {
-		$controls[] = [
-			new CLabel(_('Group'), 'groupid'),
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			$page_filter->getGroupsCB(['action' => 'javascript: reloadPopup(this.form);'])
-		];
-	}
-
-	// Show Type dropdown in header for help items.
-	if ($data['popup_type'] === 'help_items') {
-		$cmb_types = new CComboBox('itemtype', $options['itemtype'], 'javascript: reloadPopup(this.form);');
-
-		foreach ($data['allowed_item_types'] as $type) {
-			$cmb_types->addItem($type, item_type2str($type));
-		}
-
-		$controls[] = [
-			new CLabel(_('Type'), 'itemtype'),
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			$cmb_types
-		];
-	}
-
-	// Show Host dropdown in header for these specified sources.
-	$show_host_cmb_box = ['triggers', 'items', 'applications', 'graphs', 'graph_prototypes', 'item_prototypes'];
-	if (in_array($data['popup_type'], $show_host_cmb_box)
-			&& ($data['popup_type'] !== 'item_prototypes' || !$options['parent_discoveryid'])) {
-		$controls[] = [
-			new CLabel(_('Host'), 'hostid'),
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			$page_filter->getHostsCB(['action' => 'javascript: reloadPopup(this.form);'])
-		];
-	}
+	$empty_btn = null;
 }
 
-if (in_array($data['popup_type'], ['applications', 'application_prototypes', 'triggers'])) {
-	if (!array_key_exists('noempty', $options)) {
-		$value1 = strpos($options['dstfld1'], 'id') !== false ? 0 : '';
-		$value2 = strpos($options['dstfld2'], 'id') !== false ? 0 : '';
-		$value3 = strpos($options['dstfld3'], 'id') !== false ? 0 : '';
+// Add host group multiselect control.
+if (array_key_exists('groups', $data['filter'])) {
+	$multiselect_options = $data['filter']['groups'];
+	$multiselect_options['popup']['parameters']['dstfrm'] = $header_form->getId();
 
-		$empty_script = get_window_opener($options['dstfrm'], $options['dstfld1'], $value1);
-		$empty_script .= get_window_opener($options['dstfrm'], $options['dstfld2'], $value2);
-		$empty_script .= get_window_opener($options['dstfrm'], $options['dstfld3'], $value3);
-		$empty_script .= ' overlayDialogueDestroy(jQuery(this).closest("[data-dialogueid]").attr("data-dialogueid"));';
-		$empty_script .= ' return false;';
+	$hostgroup_ms = (new CMultiSelect($multiselect_options))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH);
+	$controls[] = (new CFormList())->addRow(new CLabel(_('Host group'), 'popup_host_group_ms'), $hostgroup_ms);
 
-		$controls[] = [(new CButton('empty', _('Empty')))->onClick($empty_script)];
+	$output['script_inline'] .=
+		$hostgroup_ms->getPostJS().
+		'var overlay = overlays_stack.end();'.
+		'jQuery(".multiselect", overlay.$dialogue).each(function(i, ms) {'.
+			'jQuery(ms).on("change", {overlay: overlay}, function(e) {'.
+				'var groups = jQuery(this).multiSelect("getData").map(i => i.id),'.
+					'options = groups.length ? {groupid: groups[0]} : {filter_groupid_rst: 1, groupid: []};'.
+					'new_opts = jQuery.extend(e.data.overlay.options, options);'.
+				'PopUp(e.data.overlay.action, new_opts, e.data.overlay.dialogueid);'.
+			'});'.
+		'});';
+}
+
+// Add host multiselect.
+if (array_key_exists('hosts', $data['filter'])) {
+	$multiselect_options = $data['filter']['hosts'];
+	$multiselect_options['popup']['parameters']['dstfrm'] = $header_form->getId();
+
+	$host_ms = (new CMultiSelect($multiselect_options))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH);
+	if ($multiselect_options['disabled']) {
+		$host_ms->setTitle(_('You can not switch hosts for current selection.'));
 	}
+	$controls[] = (new CFormList())->addRow(new CLabel(_('Host'), 'popup_host_ms'), [$empty_btn, $host_ms]);
+
+	$output['script_inline'] .=
+		$host_ms->getPostJS().
+		'var overlay = overlays_stack.end();'.
+		'jQuery(".multiselect", overlay.$dialogue).each(function(i, ms) {'.
+			'jQuery(ms).on("change", {overlay: overlay}, function(e) {'.
+				'var hosts = jQuery(this).multiSelect("getData").map(i => i.id),'.
+					'options = hosts.length ? {hostid: hosts[0]} : {filter_hostid_rst: 1, hostid: []};'.
+					'new_opts = jQuery.extend(e.data.overlay.options, options);'.
+				'PopUp(e.data.overlay.action, new_opts, e.data.overlay.dialogueid);'.
+			'});'.
+		'});';
+}
+elseif ($empty_btn) {
+	$controls[] = (new CFormList())->addRow($empty_btn);
+}
+
+// Show Type dropdown in header for help items.
+if ($data['popup_type'] === 'help_items') {
+	$types_select = (new CSelect('itemtype'))
+		->setId('itemtype')
+		->setFocusableElementId('label-itemtype')
+		->setAttribute('autofocus', 'autofocus')
+		->setValue($options['itemtype']);
+
+	$output['script_inline'] .= '$("#itemtype").on("change", (e) => {'.
+		'reloadPopup($(e.target).closest("form").get(0));'.
+	'});';
+
+	$header_form
+		->addVar('srctbl', $data['popup_type'])
+		->addVar('srcfld1', $options['srcfld1'])
+		->addVar('dstfrm', $options['dstfrm'])
+		->addVar('dstfld1', $options['dstfld1']);
+
+	foreach (CControllerPopupGeneric::ALLOWED_ITEM_TYPES as $type) {
+		$types_select->addOption(new CSelectOption($type, item_type2str($type)));
+	}
+
+	$controls[] = [
+		new CLabel(_('Type'), $types_select->getFocusableElementId()),
+		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+		$types_select
+	];
 }
 
 if ($controls) {
-	$header_form->addItem(new CList($controls));
+	$header_form->addItem($controls);
 	$output['controls'] = $header_form->toString();
 }
 
@@ -133,10 +151,6 @@ if ($data['form']) {
 
 $table_columns = [];
 
-if ($page_filter->hostsAll) {
-	$table_columns[] = _('Host');
-}
-
 if ($data['multiselect'] && $form !== null) {
 	$ch_box = (new CColHeader(
 		(new CCheckBox('all_records'))->onClick("javascript: checkAll('".$form->getName()."', 'all_records', 'item');")
@@ -147,6 +161,10 @@ if ($data['multiselect'] && $form !== null) {
 
 $table = (new CTableInfo())->setHeader(array_merge($table_columns, $data['table_columns']));
 
+if ($data['preselect_required']) {
+	$table->setNoDataMessage(_('Specify some filter condition to see the values.'));
+}
+
 $js_action_onclick = ' jQuery(this).removeAttr("onclick");'.
 	' overlayDialogueDestroy(jQuery(this).closest("[data-dialogueid]").attr("data-dialogueid"));'.
 	' return false;';
@@ -158,9 +176,10 @@ switch ($data['popup_type']) {
 	case 'proxies':
 	case 'host_templates':
 	case 'templates':
-	case 'applications':
-	case 'application_prototypes':
 	case 'drules':
+	case 'roles':
+	case 'api_methods':
+	case 'dashboard':
 		foreach ($data['table_records'] as $item) {
 			$check_box = $data['multiselect']
 				? new CCheckBox('item['.$item['id'].']', $item['id'])
@@ -197,19 +216,19 @@ switch ($data['popup_type']) {
 			$js_action = 'javascript: addValue('.zbx_jsvalue($options['reference']).', '.
 					zbx_jsvalue($user['userid']).', '.$options['parentid'].');';
 
-			$alias = (new CLink($user['alias'], 'javascript:void(0);'))
+			$username = (new CLink($user['username'], 'javascript:void(0);'))
 				->setId('spanid'.$user['userid'])
 				->onClick($js_action.$js_action_onclick);
 
-			$table->addRow([$check_box, $alias, $user['name'], $user['surname']]);
+			$table->addRow([$check_box, $username, $user['name'], $user['surname']]);
 
 			$entry = [];
 			$srcfld1 = $options['srcfld1'];
 			if ($srcfld1 === 'userid') {
 				$entry['id'] = $user['userid'];
 			}
-			elseif ($srcfld1 === 'alias') {
-				$entry['name'] = $user['alias'];
+			elseif ($srcfld1 === 'username') {
+				$entry['name'] = $user['username'];
 			}
 
 			$srcfld2 = $options['srcfld2'];
@@ -231,18 +250,8 @@ switch ($data['popup_type']) {
 				? new CCheckBox('item['.$item['usrgrpid'].']', $item['usrgrpid'])
 				: null;
 
-			if ($data['multiselect']) {
-				$js_action = "javascript: addValue(".zbx_jsvalue($options['reference']).', '.
-						zbx_jsvalue($item['usrgrpid']).', '.$options['parentid'].');';
-			}
-			else {
-				$values = [
-					$options['dstfld1'] => $item[$options['srcfld1']],
-					$options['dstfld2'] => $item[$options['srcfld2']]
-				];
-				$js_action = 'javascript: addValues('.zbx_jsvalue($options['dstfrm']).', '.
-						zbx_jsvalue($values).', '.$options['parentid'].');';
-			}
+			$js_action = "javascript: addValue(".zbx_jsvalue($options['reference']).', '.
+				zbx_jsvalue($item['usrgrpid']).', '.$options['parentid'].');';
 
 			$name = (new CLink($item['name'], 'javascript: void(0);'))
 						->setId('spanid'.$item['usrgrpid'])
@@ -307,7 +316,7 @@ switch ($data['popup_type']) {
 			$table->addRow([
 				$check_box,
 				$description,
-				getSeverityCell($trigger['priority'], $options['config']),
+				getSeverityCell($trigger['priority']),
 				(new CSpan(triggerIndicator($trigger['status'], $trigger['state'])))
 					->addClass(triggerIndicatorStyle($trigger['status'], $trigger['state']))
 			]);
@@ -357,9 +366,10 @@ switch ($data['popup_type']) {
 
 	case 'help_items':
 		foreach ($data['table_records'] as $item) {
-			$action = get_window_opener($options['dstfrm'], $options['dstfld1'], $item[$options['srcfld1']]);
+			$action = get_window_opener($options['dstfld1'], $item[$options['srcfld1']]);
+			$action .= 'updateItemFormElements();';
 			$action .= $options['srcfld2']
-				? get_window_opener($options['dstfrm'], $options['dstfld2'], $item[$options['srcfld2']])
+				? get_window_opener($options['dstfld2'], $item[$options['srcfld2']])
 				: '';
 
 			$name = (new CLink($item['key'], 'javascript:void(0);'))->onClick($action.$js_action_onclick);
@@ -374,9 +384,9 @@ switch ($data['popup_type']) {
 				$name = $d_rule['name'].
 					NAME_DELIMITER.discovery_check2str($d_check['type'], $d_check['key_'], $d_check['ports']);
 
-				$action = get_window_opener($options['dstfrm'], $options['dstfld1'], $d_check[$options['srcfld1']]);
+				$action = get_window_opener($options['dstfld1'], $d_check[$options['srcfld1']]);
 				$action .= $options['srcfld2']
-					? get_window_opener($options['dstfrm'], $options['dstfld2'], $name)
+					? get_window_opener($options['dstfld2'], $name)
 					: '';
 
 				$table->addRow(
@@ -426,10 +436,9 @@ switch ($data['popup_type']) {
 				$description->onClick($js_action.$js_action_onclick);
 
 				$table->addRow([
-					($options['hostid'] > 0) ? null : $item['hostname'],
 					$data['multiselect'] ? new CCheckBox('item['.$checkbox_key.']', $item['itemid']) : null,
 					$description,
-					$item['key_'],
+					(new CDiv($item['key_']))->addClass(ZBX_STYLE_WORDWRAP),
 					item_type2str($item['type']),
 					itemValueTypeString($item['value_type']),
 					($data['popup_type'] === 'items')
@@ -458,17 +467,16 @@ switch ($data['popup_type']) {
 				$host = reset($item['hosts']);
 
 				$table->addRow([
-					($options['hostid'] > 0) ? null : $host['name'],
 					$data['multiselect']
 						? new CCheckBox('item['.$item[$options['srcfld1']].']', $item['itemid'])
 						: null,
 					(new CLink($item['name_expanded'], 'javascript:void(0);'))
 						->onClick('javascript: addValue('.
-							CJs::encodeJson($options['reference']).', '.
-							CJs::encodeJson($item['itemid']).', '.
+							json_encode($options['reference']).', '.
+							json_encode($item['itemid']).', '.
 							$options['parentid'].
 							');'.$js_action_onclick),
-					$item['key_'],
+					(new CDiv($item['key_']))->addClass(ZBX_STYLE_WORDWRAP),
 					item_type2str($item['type']),
 					itemValueTypeString($item['value_type']),
 					($data['popup_type'] === 'items')
@@ -516,14 +524,14 @@ switch ($data['popup_type']) {
 			$table->addRow([
 				// Multiselect checkbox.
 				$data['multiselect']
-					? new CCheckBox('item['.CJs::encodeJson($graph[$options['srcfld1']]).']', $graph['graphid'])
+					? new CCheckBox('item['.json_encode($graph[$options['srcfld1']]).']', $graph['graphid'])
 					: null,
 
 				// Clickable graph name.
 				(new CLink($graph['name'], 'javascript:void(0);'))
 					->onClick('javascript: addValue('.
-						CJs::encodeJson($options['reference']).', '.
-						CJs::encodeJson($graph['graphid']).', '.
+						json_encode($options['reference']).', '.
+						json_encode($graph['graphid']).', '.
 						$options['parentid'].
 						');'.$js_action_onclick
 					),
@@ -532,90 +540,94 @@ switch ($data['popup_type']) {
 				$graphtype
 			]);
 
-			// For a "popup_reference".
+			// For returned data array.
 			$graph = [
 				'id' => $graph['graphid'],
-				'name' => reset($graph['hosts'])['name'].NAME_DELIMITER.$graph['name']
+				'name' => $options['patternselect']
+					? $graph['name']
+					: reset($graph['hosts'])['name'].NAME_DELIMITER.$graph['name']
 			];
 		}
 		unset($graph);
 		break;
 
-	case 'screens':
-		foreach ($data['table_records'] as $screen) {
-			$checkbox_key = is_numeric($screen[$options['srcfld1']])
-				? $screen[$options['srcfld1']]
-				: zbx_jsValue($screen[$options['srcfld1']]);
+	case 'valuemap_names':
+		$inline_js = 'addValue('.json_encode($options['reference']).',%1$s,'.$options['parentid'].');%2$s';
 
-			$check_box = $data['multiselect']
-				? new CCheckBox('item['.$checkbox_key.']', $screen['screenid'])
-				: null;
-
-			$name = new CLink($screen['name'], 'javascript:void(0);');
-
-			if ($data['multiselect']) {
-				$js_action = 'javascript: addValue('.zbx_jsvalue($options['reference']).', '.
-					zbx_jsvalue($screen['screenid']).');';
-			}
-			else {
-				$values = [
-					$options['dstfld1'] => $screen[$options['srcfld1']],
-					$options['dstfld2'] => $screen[$options['srcfld2']]
-				];
-				$js_action = 'javascript: addValues('.zbx_jsvalue($options['dstfrm']).', '.zbx_jsvalue($values).');';
-			}
-			$name->onClick($js_action.$js_action_onclick);
-
-			$table->addRow([$check_box, $name]);
+		foreach ($data['table_records'] as $valuemap) {
+			$table->addRow([
+				new CCheckBox('item['.$valuemap['id'].']', $valuemap['id']),
+				(new CLink($valuemap['name'], '#'))
+					->setId('spanid'.$valuemap['id'])
+					->onClick(sprintf($inline_js, $valuemap['id'], $js_action_onclick))
+			]);
 		}
 		break;
 
-	case 'scripts':
-		foreach ($data['table_records'] as $script) {
-			$description = new CLink($script['name'], 'javascript:void(0);');
+	case 'valuemaps':
+		$inline_js = 'addValue('.json_encode($options['reference']).',%1$s,'.$options['parentid'].');%2$s';
 
+		foreach ($data['table_records'] as $valuemap) {
+			$name = [];
 			$check_box = $data['multiselect']
-				? new CCheckBox('scripts['.zbx_jsValue($script[$options['srcfld1']]).']', $script['scriptid'])
+				? new CCheckBox('item['.$valuemap['id'].']', $valuemap['id'])
 				: null;
 
-			if ($data['multiselect']) {
-				$js_action = 'javascript: addValue('.zbx_jsvalue($options['reference']).', '.
-					zbx_jsvalue($script['scriptid']).');';
-			}
-			else {
-				$values = [
-					$options['dstfld1'] => $script[$options['srcfld1']],
-					$options['dstfld2'] => $script[$options['srcfld2']]
-				];
-				$js_action = 'javascript: addValues('.zbx_jsvalue($options['dstfrm']).', '.
-					zbx_jsvalue($values).');';
-			}
-			$description->onClick($js_action.$js_action_onclick);
+			$name[] = (new CSpan($valuemap['hostname']))->addClass(ZBX_STYLE_GREY);
+			$name[] = NAME_DELIMITER;
 
-			if ($script['type'] == ZBX_SCRIPT_TYPE_CUSTOM_SCRIPT) {
-				switch ($script['execute_on']) {
-					case ZBX_SCRIPT_EXECUTE_ON_AGENT:
-						$script_execute_on = _('Agent');
-						break;
-					case ZBX_SCRIPT_EXECUTE_ON_SERVER:
-						$script_execute_on = _('Server');
-						break;
-					case ZBX_SCRIPT_EXECUTE_ON_PROXY:
-						$script_execute_on = _('Server (proxy)');
-						break;
+			if (array_key_exists('_disabled', $valuemap) && $valuemap['_disabled']) {
+				if ($data['multiselect']) {
+					$check_box->setChecked(1);
+					$check_box->setEnabled(false);
 				}
+				$name[] = (new CSpan($valuemap['name']))->addClass(ZBX_STYLE_GREY);
+
+				unset($data['table_records'][$valuemap['id']]);
 			}
 			else {
-				$script_execute_on = '';
+				$js_action = 'addValue('.json_encode($options['reference']).', '.
+					json_encode($valuemap['id']).', '.$options['parentid'].');';
+
+				$name[] = (new CLink($valuemap['name'], '#'))
+					->setId('spanid'.$valuemap['id'])
+					->onClick(sprintf($inline_js, $valuemap['id'], $js_action_onclick));
 			}
-			$table->addRow([
-				$check_box,
-				$description,
-				$script_execute_on,
-				zbx_nl2br(htmlspecialchars($script['command'], ENT_COMPAT, 'UTF-8')),
-			]);
+
+			$mappings_table = [];
+
+			foreach (array_slice($valuemap['mappings'], 0, 3) as $mapping) {
+				switch ($mapping['type']) {
+					case VALUEMAP_MAPPING_TYPE_EQUAL:
+						$value = '='.$mapping['value'];
+						break;
+
+					case VALUEMAP_MAPPING_TYPE_GREATER_EQUAL:
+						$value = '>='.$mapping['value'];
+						break;
+
+					case VALUEMAP_MAPPING_TYPE_LESS_EQUAL:
+						$value = '<='.$mapping['value'];
+						break;
+
+					case VALUEMAP_MAPPING_TYPE_DEFAULT:
+						$value = new CTag('em', true, _('default'));
+						break;
+
+					default:
+						$value = $mapping['value'];
+				}
+
+				$mappings_table[] = new CDiv($value);
+				$mappings_table[] = new CDiv('⇒');
+				$mappings_table[] = new CDiv($mapping['newvalue']);
+			}
+
+			$hellip = (count($valuemap['mappings']) > 3) ? '&hellip;' : null;
+			$table->addRow([$check_box, $name, [
+				(new CDiv($mappings_table))->addClass(ZBX_STYLE_VALUEMAP_MAPPINGS_TABLE), $hellip
+			]]);
 		}
-		unset($data['table_records']);
 		break;
 }
 
@@ -626,29 +638,33 @@ if ($data['multiselect'] && $form !== null) {
 			'title' => _('Select'),
 			'class' => '',
 			'isSubmit' => true,
-			'action' => 'return addSelectedValues('.zbx_jsvalue($form->getId()).', '.
-				zbx_jsvalue($options['reference']).', '.$options['parentid'].');'
+			'action' => 'return addSelectedValues('.zbx_jsvalue($options['reference']).', '.$options['parentid'].');'
 		]
 	];
 }
 
-$types = ['users', 'templates', 'hosts', 'host_templates', 'host_groups', 'applications', 'application_prototypes',
-	'proxies', 'items', 'item_prototypes', 'graphs', 'graph_prototypes'
+// Types require results returned as array.
+$types = ['users', 'usrgrp', 'templates', 'hosts', 'host_templates', 'host_groups', 'proxies', 'items',
+	'item_prototypes', 'graphs', 'graph_prototypes', 'roles', 'api_methods', 'valuemaps', 'dashboard'
 ];
+
 if (array_key_exists('table_records', $data) && (in_array($data['popup_type'], $types) || $data['multiselect'])) {
-	$output['script_inline'] .= 'var popup_reference = '.zbx_jsvalue($data['table_records'], true).';';
+	$output['data'] = $data['table_records'];
 }
 
-$output['script_inline'] .= '
-jQuery(document).ready(function() {
-	cookie.init();
-	chkbxRange.init();
-});';
+$output['script_inline'] =
+	'jQuery(document).ready(function() {'.
+		$output['script_inline'].
+		'cookie.init();'.
+		'chkbxRange.init();'.
+	'});';
 
 if ($form) {
 	$form->addItem([
 		$table,
-		(new CInput('submit', 'submit'))->addStyle('display: none;')
+		(new CInput('submit', 'submit'))
+			->addStyle('display: none;')
+			->removeId()
 	]);
 	$output['body'] = (new CDiv([$data['messages'], $form]))->toString();
 }
@@ -661,4 +677,4 @@ if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
 	$output['debug'] = CProfiler::getInstance()->make()->toString();
 }
 
-echo (new CJson())->encode($output);
+echo json_encode($output);
